pub struct LifecycleParams {
pub image_pull_delay: Option<u32>,
pub image_pull_jitter: Option<u32>,
pub pod_startup_delay: Option<u32>,
pub pod_startup_jitter: Option<u32>,
}Fields
image_pull_delay: Option<u32>image_pull_jitter: Option<u32>pod_startup_delay: Option<u32>pod_startup_jitter: Option<u32>Trait Implementations
Sourceimpl Clone for LifecycleParams
impl Clone for LifecycleParams
Sourcefn clone(&self) -> LifecycleParams
fn clone(&self) -> LifecycleParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LifecycleParams
impl Debug for LifecycleParams
Sourceimpl Default for LifecycleParams
impl Default for LifecycleParams
Sourcefn default() -> LifecycleParams
fn default() -> LifecycleParams
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for LifecycleParams
impl<'de> Deserialize<'de> for LifecycleParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LifecycleParams
impl JsonSchema for LifecycleParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LifecycleParams
impl RefUnwindSafe for LifecycleParams
impl Send for LifecycleParams
impl Sync for LifecycleParams
impl Unpin for LifecycleParams
impl UnsafeUnpin for LifecycleParams
impl UnwindSafe for LifecycleParams