pub struct SimulationDriverConfig {
pub args: Option<Vec<String>>,
pub image: String,
pub namespace: String,
pub port: i32,
pub secrets: Option<Vec<String>>,
pub trace_path: String,
pub virtual_ns_prefix: String,
pub cert_manager_issuer: String,
}Fields
args: Option<Vec<String>>image: Stringnamespace: Stringport: i32secrets: Option<Vec<String>>trace_path: Stringvirtual_ns_prefix: Stringcert_manager_issuer: StringTrait Implementations
Sourceimpl Clone for SimulationDriverConfig
impl Clone for SimulationDriverConfig
Sourcefn clone(&self) -> SimulationDriverConfig
fn clone(&self) -> SimulationDriverConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SimulationDriverConfig
impl Debug for SimulationDriverConfig
Sourceimpl Default for SimulationDriverConfig
impl Default for SimulationDriverConfig
Sourcefn default() -> SimulationDriverConfig
fn default() -> SimulationDriverConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SimulationDriverConfig
impl<'de> Deserialize<'de> for SimulationDriverConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SimulationDriverConfig
impl JsonSchema for SimulationDriverConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SimulationDriverConfig
impl RefUnwindSafe for SimulationDriverConfig
impl Send for SimulationDriverConfig
impl Sync for SimulationDriverConfig
impl Unpin for SimulationDriverConfig
impl UnsafeUnpin for SimulationDriverConfig
impl UnwindSafe for SimulationDriverConfig